
package de.ivu.elect.presentation.wahlrechtspruefung.table;

import java.util.function.Function;

import de.ivu.elect.business.wahlrechtspruefung.entity.Pruefkriterium;
import de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants;
import de.ivu.elect.presentation.table.DefaultColumnEntry;
import de.ivu.elect.jee.presentation.dynamictable.ColumnType;

import de.ivu.elect.jee.faces.Messages;

@javax.enterprise.inject.Vetoed
public class AbstractPruefkriteriumColumn<E extends Pruefkriterium> extends
            DefaultColumnEntry<E>
        {
    private static final long serialVersionUID = 1L;

    @Deprecated // Eindeutige Id vergeben, wichtig für Spaltenreihenfolge ELECT-4631
    protected AbstractPruefkriteriumColumn(Messages messages, String headerKey, ColumnType type, Function<E, Object> getter) {
      super(messages, headerKey, type, getter);
    }

    protected  AbstractPruefkriteriumColumn(String id, Messages messages, String headerKey, ColumnType type, Function<E, Object> getter) {
      super(id, messages, headerKey, type, getter);
    }

            
            public static <E extends Pruefkriterium> AbstractPruefkriteriumColumn<E> createPruefkriteriumFristInTagenBisZurWahlColumn(Messages messages){
            return new AbstractPruefkriteriumColumn<>("Pruefkriterium-FristInTagenBisZurWahl", messages, de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants.MESSAGE_KEY_FRIST_IN_TAGEN_BIS_ZUR_WAHL_EINZAHL,
                            ColumnType.LONG
                        , Pruefkriterium::getFristInTagenBisZurWahl);
            }




                    
            public static <E extends Pruefkriterium> AbstractPruefkriteriumColumn<E> createPruefkriteriumHeilungsfaehigColumn(Messages messages){
            return new AbstractPruefkriteriumColumn<>("Pruefkriterium-Heilungsfaehig", messages, de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants.MESSAGE_KEY_HEILUNGSFAEHIG_EINZAHL,
                            ColumnType.BOOLEAN
                        , Pruefkriterium::getHeilungsfaehig);
            }




                    
            public static <E extends Pruefkriterium> AbstractPruefkriteriumColumn<E> createPruefkriteriumKannIrrelevantSeinColumn(Messages messages){
            return new AbstractPruefkriteriumColumn<>("Pruefkriterium-KannIrrelevantSein", messages, de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants.MESSAGE_KEY_KANN_IRRELEVANT_SEIN_EINZAHL,
                            ColumnType.BOOLEAN
                        , Pruefkriterium::getKannIrrelevantSein);
            }




                    
            public static <E extends Pruefkriterium> AbstractPruefkriteriumColumn<E> createPruefkriteriumKategorieColumn(Messages messages){
            return new AbstractPruefkriteriumColumn<>("Pruefkriterium-Kategorie", messages, de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants.MESSAGE_KEY_KATEGORIE_EINZAHL,
                            ColumnType.STRING
                        , Pruefkriterium::getKategorie);
            }




                    
            public static <E extends Pruefkriterium> AbstractPruefkriteriumColumn<E> createPruefkriteriumKriteriumtextColumn(Messages messages){
            return new AbstractPruefkriteriumColumn<>("Pruefkriterium-Kriteriumtext", messages, de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants.MESSAGE_KEY_KRITERIUMTEXT_EINZAHL,
                            ColumnType.STRING
                        , Pruefkriterium::getKriteriumtext);
            }




                    
            public static <E extends Pruefkriterium> AbstractPruefkriteriumColumn<E> createPruefkriteriumPositionColumn(Messages messages){
            return new AbstractPruefkriteriumColumn<>("Pruefkriterium-Position", messages, de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants.MESSAGE_KEY_POSITION_EINZAHL,
                            ColumnType.LONG
                        , Pruefkriterium::getPosition);
            }




                    
            public static <E extends Pruefkriterium> AbstractPruefkriteriumColumn<E> createPruefkriteriumPruefkriteriumBezugColumn(Messages messages){
            return new AbstractPruefkriteriumColumn<>("Pruefkriterium-PruefkriteriumBezug", messages, de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants.MESSAGE_KEY_PRUEFKRITERIUM_BEZUG_EINZAHL,
                            ColumnType.ENUM
                        , Pruefkriterium::getPruefkriteriumBezug);
            }




                    
            public static <E extends Pruefkriterium> AbstractPruefkriteriumColumn<E> createPruefkriteriumTeilDerSofortpruefungColumn(Messages messages){
            return new AbstractPruefkriteriumColumn<>("Pruefkriterium-TeilDerSofortpruefung", messages, de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants.MESSAGE_KEY_TEIL_DER_SOFORTPRUEFUNG_EINZAHL,
                            ColumnType.BOOLEAN
                        , Pruefkriterium::getTeilDerSofortpruefung);
            }




                    
            public static <E extends Pruefkriterium> AbstractPruefkriteriumColumn<E> createPruefkriteriumTextFuerProtokollErfuelltColumn(Messages messages){
            return new AbstractPruefkriteriumColumn<>("Pruefkriterium-TextFuerProtokollErfuellt", messages, de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants.MESSAGE_KEY_TEXT_FUER_PROTOKOLL_ERFUELLT_EINZAHL,
                            ColumnType.STRING
                        , Pruefkriterium::getTextFuerProtokollErfuellt);
            }




                    
            public static <E extends Pruefkriterium> AbstractPruefkriteriumColumn<E> createPruefkriteriumTextFuerProtokollFristColumn(Messages messages){
            return new AbstractPruefkriteriumColumn<>("Pruefkriterium-TextFuerProtokollFrist", messages, de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants.MESSAGE_KEY_TEXT_FUER_PROTOKOLL_FRIST_EINZAHL,
                            ColumnType.STRING
                        , Pruefkriterium::getTextFuerProtokollFrist);
            }




                    
            public static <E extends Pruefkriterium> AbstractPruefkriteriumColumn<E> createPruefkriteriumTextFuerProtokollNichtErfuelltColumn(Messages messages){
            return new AbstractPruefkriteriumColumn<>("Pruefkriterium-TextFuerProtokollNichtErfuellt", messages, de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants.MESSAGE_KEY_TEXT_FUER_PROTOKOLL_NICHT_ERFU_EINZAHL,
                            ColumnType.STRING
                        , Pruefkriterium::getTextFuerProtokollNichtErfuellt);
            }




                    
            public static <E extends Pruefkriterium> AbstractPruefkriteriumColumn<E> createPruefkriteriumUnterkategorieColumn(Messages messages){
            return new AbstractPruefkriteriumColumn<>("Pruefkriterium-Unterkategorie", messages, de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants.MESSAGE_KEY_UNTERKATEGORIE_EINZAHL,
                            ColumnType.STRING
                        , Pruefkriterium::getUnterkategorie);
            }




                    
            public static <E extends Pruefkriterium> AbstractPruefkriteriumColumn<E> createPruefkriteriumWahlrechtlichRelevantColumn(Messages messages){
            return new AbstractPruefkriteriumColumn<>("Pruefkriterium-WahlrechtlichRelevant", messages, de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants.MESSAGE_KEY_WAHLRECHTLICH_RELEVANT_EINZAHL,
                            ColumnType.BOOLEAN
                        , Pruefkriterium::getWahlrechtlichRelevant);
            }




            
    
        public static <E extends Pruefkriterium> AbstractPruefkriteriumColumn<E> createWahlColumn(Messages messages, ColumnType type, Function<E, Object> getter){
        return new AbstractPruefkriteriumColumn<>("Pruefkriterium-Wahl", messages, de.ivu.elect.business.wahlrechtspruefung.entity.PruefkriteriumConstants.MESSAGE_KEY_WAHL_ID_EINZAHL,
        type
        , getter);
        }

    



    }
